@@ -5,6 +5,7 @@ mod flat_scan;
 mod fold;
 mod iter;
 mod list;
+mod map;
 mod option;
 mod result;
 mod take;
@@ -16,6 +17,7 @@ pub use flat_scan::*;
 pub use fold::*;
 pub use iter::*;
 pub use list::*;
+pub use map::*;
 pub use option::*;
 pub use result::*;
 pub use take::*;
